import React, { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import styles from "./UserSearchResults.module.css";

const UserSearchResults = () => {
  const { personId } = useParams(); // Get personId from the route
  const [personDetails, setPersonDetails] = useState(null);

  useEffect(() => {
    // Retrieve the stored person details from localStorage
    const storedPerson = localStorage.getItem("selectedPerson");
    if (storedPerson) {
      const parsedPerson = JSON.parse(storedPerson);

      // Verify that the personId matches the stored person's ID
      if (parsedPerson.peopleId === parseInt(personId, 10)) {
        setPersonDetails(parsedPerson);
      } else {
        setPersonDetails(null); // If mismatched, clear details
      }
    }
  }, [personId]);

  if (!personDetails) return <p>No details available for this person.</p>;

  return (
    <div className={styles.container}>
      <h2>Person Details</h2>
      <div className={styles.details}>
        <p>
          <strong>Full Name:</strong> {personDetails.firstName}{" "}
          {personDetails.middleName} {personDetails.lastName}
        </p>
        <p>
          <strong>Nickname:</strong> {personDetails.nickName || "N/A"}
        </p>
        <p>
          <strong>Tech Alumni Chapter:</strong>{" "}
          {personDetails.techAlumniChapter}
        </p>
        <p>
          <strong>Class Year:</strong> {personDetails.classYear}
        </p>
        <p>
          <strong>Graduation Year:</strong> {personDetails.gradYear} (
          {personDetails.gradSemester})
        </p>
        <p>
          <strong>Gender:</strong> {personDetails.gender}
        </p>

        <p>
          <strong>Degrees:</strong>
        </p>
        <ul>
          {(personDetails.degrees || []).map((degree, index) => (
            <li key={index}>
              {degree.degreeYear}, {degree.degreeDepartment} (
              {degree.degreeCollege})
            </li>
          ))}
        </ul>

        <p>
          <strong>Addresses:</strong>
        </p>
        <ul>
          {(personDetails.addresses || []).map((address, index) => (
            <li key={index}>
              {address.city}, {address.state}
            </li>
          ))}
        </ul>

        <p>
          <strong>Contact Numbers:</strong>
        </p>
        <ul>
          {(personDetails.contactNumbers || []).map((contact, index) => (
            <li key={index}>{contact}</li>
          ))}
        </ul>

        <p>
          <strong>Involvements:</strong>
        </p>
        <ul>
          {(personDetails.involvements || []).map((involvement, index) => (
            <li key={index}>{involvement.involvementName}</li>
          ))}
        </ul>
      </div>
    </div>
  );
};

export default UserSearchResults;
